@@ -34,22 +34,22 @@ class BigList extends List
 	super (rows, mult);
     }
 	
-    public Dimension preferredSize ()
+    public Dimension getPreferredSize ()
     {
 	return new Dimension (200, 150);
     }
 
-    public Dimension preferredSize (int rows)
+    public Dimension getPreferredSize (int rows)
     {
 	return new Dimension (200, 150);
     }
 
-    public Dimension minimumSize ()
+    public Dimension getMinimumSize ()
     {
 	return new Dimension (200, 150);
     }
 
-    public Dimension minimumSize (int rows)
+    public Dimension getMinimumSize (int rows)
     {
 	return new Dimension (200, 150);
     }
